<?php
/**
 * Sample code for the CreatePickupRequest Canada Post service.
 * 
 * The GetPickupPrice service creates a request that returns the price of a one-time on-demand pickup.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username and password are imported from the following file
// CPCWS_Pickup_PHP_Samples\REST\pickup\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];
$customer = $userProperties['customerNumber'];

// REST URI
$service_url = 'https://stg30.soa-gw.canadapost.ca/enab/' . $customer . '/pickuprequest/price';

$xmlRequest = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<pickup-details xmlns="http://www.canadapost.ca/ws/pickuprequest">
	<date>2019-02-22</date>
</pickup-details>
XML;

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2); 
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Mozilla cacerts
curl_setopt($curl, CURLOPT_POST, true);
curl_setopt($curl, CURLOPT_POSTFIELDS, $xmlRequest);
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/vnd.cpc.pickuprequest+xml', 'Accept:application/vnd.cpc.pickuprequest+xml', 'Accept-Language:en-CA'));
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n";

// Example of using SimpleXML to parse xml response
libxml_use_internal_errors(true);
$xml = simplexml_load_string('<root>' . preg_replace('/<\?xml.*\?>/','',$curl_response) . '</root>');
//var_dump($xml);

if (!$xml) {
	echo 'Failed loading XML' . "\n";
	echo $curl_response . "\n";
	foreach(libxml_get_errors() as $error) {
		echo "\t" . $error->message;
	}
} else {
	if ($xml->{'pickup-request-price'} ) {
		$price = $xml->{'pickup-request-price'}->children('http://www.canadapost.ca/ws/pickuprequest');
		
        echo  'Pre-tax Amount: ' . $price->{'pre-tax-amount'} . "\n";
        echo  'GST Amount: ' . $price->{'gst-amount'} . "\n";
        echo  'PST Amount: ' . $price->{'pst-amount'} . "\n";
        echo  'HST Amount: ' . $price->{'hst-amount'} . "\n";
        echo  'Due Amount: ' . $price->{'due-amount'} . "\n";
	}
	if ($xml->{'messages'} ) {					
		$messages = $xml->{'messages'}->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

curl_close($curl);
?>

