<?php
/**
 * Sample code for the PickupRequestDetails Canada Post service.
 * 
 * The GetPickupRequestDetails service gets all available details on a given Pickup Request.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username and password are imported from the following file
// CPCWS_Pickup_PHP_Samples\REST\pickup\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];
$customer = $userProperties['customerNumber'];
$requestId = '0074698052';

// REST URI
$service_url = 'https://stg30.soa-gw.canadapost.ca/enab/' . $customer . '/pickuprequest/'. $requestId .'/details';

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2); 
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Mozilla cacerts
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Accept:application/vnd.cpc.pickup+xml', 'Accept-Language:en-CA'));
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n\n";

curl_close($curl);

// Example of using SimpleXML to parse xml response
libxml_use_internal_errors(true);
//$xml = simplexml_load_string($curl_response);
$xml = simplexml_load_string('<root>' . preg_replace('/<\?xml.*\?>/','',$curl_response) . '</root>');
$xml = simplexml_load_string($curl_response);

if (!$xml) {
	echo 'Failed loading XML' . "\n";
	echo $curl_response . "\n";
	foreach(libxml_get_errors() as $error) {
		echo "\t" . $error->message;
	}
} else {
	//$pickup = $xml->children('http://www.canadapost.ca/ws/pickup/availability');
	if ( $xml->{'pickup-request-header'} ) {
		$header = $xml->{'pickup-request-header'};
		$details = $xml->{'pickup-request-details'};
		
		echo "Request ID: " . $header->{'request-id'} . "\n";
		echo "Request status: " . $header->{'request-status'} . "\n";
		echo "Pickup type: " . $header->{'pickup-type'} . "\n";
		echo "Request date: " . $header->{'request-date'} . "\n";
		
		echo "\nPickup Location\n";
		echo "Business Address flag: " . $details->{'pickup-location'}->{'business-address-flag'} . "\n";
		if($details->{'pickup-location'}->{'alternate-address'}){
			$alternatAddress = $details->{'pickup-location'}->{'alternate-address'};
			echo "Company: " . $alternatAddress->{'company'} . "\n";
			echo "Address line 1: " . $alternatAddress->{'address-line-1'} . "\n";
			echo "City: " . $alternatAddress->{'city'} . "\n";
			echo "Province: " . $alternatAddress->{'province'} . "\n";
			echo "Postal code: " . $alternatAddress->{'postal-code'} . "\n";
		}
		
		echo "\nContact Info\n";
		echo "Contact name: " . $details->{'contact-info'}->{'contact-name'} . "\n";
		echo "Email: " . $details->{'contact-info'}->{'email'} . "\n";
		echo "Contact phone: " . $details->{'contact-info'}->{'contact-phone'} . "\n";
		echo "Telephone ext: " . $details->{'contact-info'}->{'telephone-ext'} . "\n\n";
		
		echo "Pickup instructions: " . $details->{'location-details'}->{'pickup-instructions'} . "\n";
		echo "Pickup volume: " . $details->{'pickup-volume'};
	} else {
		$messages = $xml->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

?>

