<?php
/**
 * Sample code for the GetPickupRequests Canada Post service.
 * 
 * The GetPickupRequests service retrieves links to existing open pickup requests.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username and password are imported from the following file
// CPCWS_Pickup_PHP_Samples\REST\pickup\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];
$customer = $userProperties['customerNumber'];

// REST URI
$service_url = 'https://stg30.soa-gw.canadapost.ca/enab/' . $customer . '/pickuprequest';

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2); 
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Mozilla cacerts
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Accept:application/vnd.cpc.pickuprequest+xml', 'Accept-Language:en-CA'));
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n\n";

curl_close($curl);

// Example of using SimpleXML to parse xml response
libxml_use_internal_errors(true);
$xml = simplexml_load_string('<root>' . preg_replace('/<\?xml.*\?>/','',$curl_response) . '</root>');
$xml = simplexml_load_string(preg_replace('/<\?xml.*\?>/','',$curl_response));
$xml = simplexml_load_string($curl_response);

if (!$xml) {
	echo 'Failed loading XML' . "\n";
	echo $curl_response . "\n";
	foreach(libxml_get_errors() as $error) {
		echo "\t" . $error->message;
	}
} else {
	if ( $xml->{'pickup-request'} ) {
		foreach($xml->{'pickup-request'} as $pickups){
			$pickupRequestHeader = $pickups->{'pickup-request-header'};
			echo "Request Id: " . $pickupRequestHeader->{'request-id'} . "\n";
			echo "Request Status: " . $pickupRequestHeader->{'request-status'} . "\n";
			echo "Pickup Type: " . $pickupRequestHeader->{'pickup-type'} . "\n";
			echo "Request Date: " . $pickupRequestHeader->{'request-date'} . "\n";
			foreach($pickups->{'links'}->{'link'} as $link){
				echo $link->attributes()->{'rel'} . ': ' . $link->attributes()->{'href'} . "\n";
			}
			echo "\n\n";
			
		}
	} else {
		echo 'No pickup requests returned.' . "\n";
	}
	
	if ($xml->{'messages'} ) {
		$messages = $xml->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

?>

