<?php
 /**
 * Sample code for the GetPostOfficeDetail Canada Post service.
 * 
 * The GetPostOfficeDetail service returns Post Office details such as the daily 
 * hours of operation for a given Post Office as determined by the first call.
 *
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 **/

// Your username and password are imported from the following file
// CPCWS_PostOffice_PHP_Samples\REST\postoffice\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];

// REST URI
$service_url = 'https://ct.soa-gw.canadapost.ca/rs/postoffice/102978/detail';

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2); 
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Mozilla cacerts
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Accept:application/vnd.cpc.postoffice+xml', 'Accept-Language:en-CA'));
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n";

curl_close($curl);

// Example of using SimpleXML to parse xml response
libxml_use_internal_errors(true);
$xml = simplexml_load_string($curl_response);
if (!$xml) {
	echo 'Failed loading XML' . "\n";
	echo $curl_response . "\n";
	foreach(libxml_get_errors() as $error) {
		echo "\t" . $error->message;
	}
} else {
		
	$postOffice = $xml->children('http://www.canadapost.ca/ws/postoffice');
	if ( $postOffice->{'name'} ) {
		echo 'Office Name: ' . $postOffice->{'name'} . "\n";
		echo 'Address: ' . $postOffice->{'address'}->{'office-address'} . "\n\n";
		
		foreach ( $postOffice->{'hours-list'} as $hoursListItem ) {
			echo 'Weekday: ' . $hoursListItem->{'day'} . "\n";
			foreach ( $hoursListItem->{'time'} as $timeItem ) {			
				echo 'Time: '  . $timeItem . "\n";
			}
			echo "\n";			
		}
	} else {
		$messages = $xml->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

?>

